@@ -180,20 +180,10 @@ impl DataCollection {
         &mut self, memory: memory::MemHarvest, swap: memory::MemHarvest, new_entry: &mut TimedData,
     ) {
         // Memory
-        let mem_percent = if memory.mem_total_in_kib > 0 {
-            Some((memory.mem_used_in_kib as f64) / (memory.mem_total_in_kib as f64) * 100.0)
-        } else {
-            None
-        };
-        new_entry.mem_data = mem_percent;
+        new_entry.mem_data = memory.use_percent;
 
         // Swap
-        let swap_percent = if swap.mem_total_in_kib > 0 {
-            Some((swap.mem_used_in_kib as f64) / (swap.mem_total_in_kib as f64) * 100.0)
-        } else {
-            None
-        };
-        new_entry.swap_data = swap_percent;
+        new_entry.swap_data = swap.use_percent;
 
         // In addition copy over latest data for easy reference
         self.memory_harvest = memory;
