@@ -1,7 +1,7 @@
-use beef::Cow;
 use regex::Regex;
 use serde::{Deserialize, Serialize};
 use std::{
+    borrow::Cow,
     collections::{HashMap, HashSet},
     path::PathBuf,
     str::FromStr,
@@ -79,9 +79,6 @@ pub struct ConfigFlags {
     #[builder(default, setter(strip_option))]
     pub regex: Option<bool>,
 
-    #[builder(default, setter(strip_option))]
-    pub default_widget: Option<String>,
-
     #[builder(default, setter(strip_option))]
     pub basic: Option<bool>,
 
@@ -145,6 +142,7 @@ pub struct ConfigFlags {
     #[builder(default, setter(strip_option))]
     pub search_regex_enabled_widgets: Option<Vec<WidgetIdEnabled>>,
 
+    // End hack
     #[builder(default, setter(strip_option))]
     pub mem_as_value: Option<bool>,
 
